==> haskell-warp-tls-3.4.9-137-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp-tls
version:              3.4.9
visibility:           public
id:                   warp-tls-3.4.9-Btblk5RMhh01uzaBuswVDg
key:                  warp-tls-3.4.9-Btblk5RMhh01uzaBuswVDg
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.

category:             Web, Yesod
abi:                  ff1cb35c81b6526aa16e36d1d32ab9fa
exposed:              True
exposed-modules:
    Network.Wai.Handler.WarpTLS Network.Wai.Handler.WarpTLS.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-tls
hs-libraries:         HSwarp-tls-3.4.9-Btblk5RMhh01uzaBuswVDg
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    data-default-0.7.1.2-95OdNmNpLKa9cNDp3ZlqO5
    network-3.1.4.0-HbZCj3UHcZsFvn6ftFrD4m
    recv-0.1.1-FUAi3ygNUtEOaY3jNIgoQ
    streaming-commons-0.2.3.0-6BG7IUO9tyzFcAlz4O6I16
    tls-2.0.6-BmuiHslymy76gQW8YEawa2
    tls-session-manager-0.0.5-EcQJj91njvyAulL9AF3dw3
    unliftio-0.2.25.1-CJQK5KnE2olHnUQXP11pzl
    wai-3.2.4-5eTAAfrYzv8Cj5jt7kPDLd warp-3.3.30-6f86FwsrA0q9gyhbhZhd7N

haddock-interfaces:   /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html:         /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-tls-3.4.9-138-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp-tls
version:              3.4.9
visibility:           public
id:                   warp-tls-3.4.9-2D4ga045bvI9DG3a3HUqIb
key:                  warp-tls-3.4.9-2D4ga045bvI9DG3a3HUqIb
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             HTTP over TLS support for Warp via the TLS package
description:
    SSLv1 and SSLv2 are obsoleted by IETF.
    We should use TLS 1.2 (or TLS 1.1 or TLS 1.0 if necessary).
    HTTP/2 can be negotiated by ALPN.
    API docs and the README are available at
    <http://www.stackage.org/package/warp-tls>.

category:             Web, Yesod
abi:                  5bdedf3a79548a388ae6343e159ab596
exposed:              True
exposed-modules:
    Network.Wai.Handler.WarpTLS Network.Wai.Handler.WarpTLS.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/warp-tls-3.4.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-tls
hs-libraries:         HSwarp-tls-3.4.9-2D4ga045bvI9DG3a3HUqIb
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    data-default-0.7.1.2-GUUW0V5lisrJnDmYs4YZIH
    network-3.1.4.0-480JOeNLV9o5fbqpzcHJCB
    recv-0.1.1-5ZGb4nhQKH78CtE3uGcU6q
    streaming-commons-0.2.3.0-g3TQcCBU6BNOSjTKAotw
    tls-2.0.6-AbbkodQw07u3L7IwptCXQ4
    tls-session-manager-0.0.5-7H2GCvU5CBJLV0YIQXMPYW
    unliftio-0.2.25.1-GvHGTWlohcOFK8rX6wCpFn
    wai-3.2.4-JB43hXdVXtN8JMxxOtVTHM warp-3.3.30-CrPaA8J74RpDAzaRjUdTYd

haddock-interfaces:   /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
haddock-html:         /usr/share/doc/haskell-warp-tls/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
